const VisionDeficiency = {
  NONE: 0,
  Protanopia: 1,
  Deuteranopia: 2,
  Tritanopia: 3,
  Achromatopsia: 4,
  BlurredVision: 5,
  ReducedContrast: 6
}



/**
 * 
 * @param String filter data
 * @returns String
 */
function createFilterDataUrl(filter) {
    var url =
        "data:image/svg+xml," +
          "<svg xmlns=\"http://www.w3.org/2000/svg\">" +
            "<filter id=\"f\">" +
                filter +
            "</filter>" +
          "</svg>" +
        "#f";
        // console.log(url);
    return url;
}

/**
 * 
 * @param {VisionDeficiency} visionDeficiency 
 * @returns String 
 */
function createVisionDeficiencyFilterUrl(visionDeficiency) {
  switch (visionDeficiency) {
    case VisionDeficiency.Protanopia:
      return createFilterDataUrl(
          "<feColorMatrix values=\"" +
          " 0.152  1.053 -0.205  0.000  0.000 " +
          " 0.115  0.786  0.099  0.000  0.000 " +
          "-0.004 -0.048  1.052  0.000  0.000 " +
          " 0.000  0.000  0.000  1.000  0.000 " +
          "\"/>");
    case VisionDeficiency.Deuteranopia:
      return createFilterDataUrl(
          "<feColorMatrix values=\"" +
          " 0.367  0.861 -0.228  0.000  0.000 " +
          " 0.280  0.673  0.047  0.000  0.000 " +
          "-0.012  0.043  0.969  0.000  0.000 " +
          " 0.000  0.000  0.000  1.000  0.000 " +
          "\"/>");
    case VisionDeficiency.Tritanopia:
      return createFilterDataUrl(
          "<feColorMatrix values=\"" +
          " 1.256 -0.077 -0.179  0.000  0.000 " +
          "-0.078  0.931  0.148  0.000  0.000 " +
          " 0.005  0.691  0.304  0.000  0.000 " +
          " 0.000  0.000  0.000  1.000  0.000 " +
          "\"/>");
    case VisionDeficiency.Achromatopsia:
      return createFilterDataUrl(
          "<feColorMatrix values=\"" +
          " 0.213  0.715  0.072  0.000  0.000 " +
          " 0.213  0.715  0.072  0.000  0.000 " +
          " 0.213  0.715  0.072  0.000  0.000 " +
          " 0.000  0.000  0.000  1.000  0.000 " +
          "\"/>");
    case VisionDeficiency.BlurredVision:
      return createFilterDataUrl("<feGaussianBlur stdDeviation=\"2\"/>");
    case VisionDeficiency.ReducedContrast:
      return createFilterDataUrl(
        "<feComponentTransfer>" +
        " <feFuncR type=\"gamma\" offset=\"0.5\"/>" +
        " <feFuncG type=\"gamma\" offset=\"0.5\"/>" +
        " <feFuncB type=\"gamma\" offset=\"0.5\"/>" +
        "</feComponentTransfer>");
    case VisionDeficiency.NONE:
      return "";
  }
}

function setEmulatorVisionDeficiencyMode(visionDeficiency){
  if (visionDeficiency == VisionDeficiency.NONE) {
    document.getElementById("iframe").style.filter = ""
  } else{
    document.getElementById("iframe").style.filter = "url('" + createVisionDeficiencyFilterUrl(visionDeficiency) + "')"
  }
}